bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 32. Aventiure
___________________________________________________ #### Aventv wie Bloedel mit Danchwart #### an der herberge streit
| ### <Die> Bloedelines rechen die warn alle gar ### mit tusent <halspergen> hvben si sich dar ### da Danchwart mit den knehten ob den tischen saz ### do hvop sich vnder degenen mort vn– nitlicher haz
###### 1974 | ### Also der herre Bloedel fver die tische gie ### Danchwart der marschalch in gvetlich enpfie ### willechomen her ze hvse min her Bloedelin ### waz iwer reise meine des wndert gar die sinne min
###### 1975 | ### Iane darftv mih niht grvezen sprach do Bloedelin ### wan dizze chomen daz mine daz sol din ende sin ### dvrch Hagenen dinen brvoder der Sivriden slvoc ### des engiltestv zen Hvnen vn– ander degene genvoc
###### 1976 | ### Neina herre Bloedel sprach do Danchwart ### so mohte vns balde riwen disiv hovevart ### ich was ein vil kleiner kneht do Sivrit vlos den lip ### iane weiz ich waz mir wi[70v]zet des kunec Ezeln wip
| ### Iane weiz ich dir <der> mære nimer ze sagene ### ez taten dine mage Gunther vn– Hagene ### nv wert ivch vil ellenden ir chvnnet niht genesen ### ir mvzet mit dem tode pfant daz Chriemh' wesen
###### 1978 | ### So enwelt ir niht erwinden sprach do Danchwart ### so riwet mich min vlehen daz wære baz verspart ### der snelle degen chvne von dem tische spranch ### er zoch ein scharpfez wafen daz was michel vn– lanch
###### 1979 | ### Do slvoger Bloedeline einen swinden swertes slac ### daz imz hovbet mit helme vor den fvezen lac ### daz si din morgengabe sprach Danchwart der helt ### zvo Nvodvnges brvte die dv ze frevden hast erwelt
###### 1980 | ### Si mac sich morgen mæhelen einem andern man ### wil er die brvote miete ez mac im sam ergan ### ein getriwer Hvne het im daz geseit ### daz in div kuniginne riet so groezlichiv leit
| ### Do sahen Bloedelines man ir herre lac erslagen ### daz enwolden si den gesten langer niht vertragen ### mit vf erbvrten swerten si sprvngen fvr div kint ### in eime grimme mte ia gerowez si sint
###### 1982 | ### Vil lvte rief der marschalch al die knappen an ### ir seht wol edeln knehte wie ez wil vmbe gan ### nv wert ivch ellenden als ivch des twinget not ### daz ir frvomchliche ane schande <liget> tot
###### 1983 | ### Die swerte niht enheten die reichten fvr die banch ### si hvben vz den fvzen vil manigen schamel lanch ### der Buregonden knehte in wolden niht vertragen ### da wart von swæren stvlen dvrch helme bvlen vil geslagen
###### 1984 | ### Wie grimme sich do werten div ellenden kint ### si triben vzem hvse die gewafenden sint ### doch beleib ir tot dar inne fvnf hvndert oder baz ### do was daz ingesinde von blvote rot unde naz
| ### Disiv starchen mære wrden dan geseit ### den Ezeln rechen ez was in grimme leit ### daz erslagen wære der herre un– sine man ### daz het der Hagen brvoder mit den knehten getan
###### 1986 | ### Ê manz ze hove erfvnde die Hvnen dvrch ir haz ### der garte sich zwei tvsent oder dannoch baz ### si giengen zv den knehten daz mvos et also wesen ### vn– liezen des gesindes ninder einen genesen
###### 1987 | ### Do die vil ungetriwen drvngen in daz gadem ### do hvop sich zwischen den rechen vil vngefvger kradem ### waz half ir baldez ellen si mvsen ligen tot ### dar nach in chvrcen stvnden hvop sich êngestlichiv not
###### 1988 | ### Hie mvgt ir horen wnder bi vnfvge sagen ### niwan tvsent knehte die lagen tot erslagen ### dar vber ritter zwelfe der Danchwarres man ### man sach in alterseine noch bi den vianden stan
###### 1989 | ### Der schal der was geswiftet der doz der was gelegn [71r] ### do blichte vber ahsel Danchwart der degen ### Er sprach owe der frivnde die ich verlorn han ### nv mvz ich leider eine bi minen vianden stan
| ### Div swert genote vielen vf sin eines lip ### daz mvse sit beweinen vil maniges heldes wip ### den schilt er rvochter hoher den vezzel nider baz ### do frvmt er vil der ringe mit blvte vliezende naz
###### 1991 | ### Owe mir dirre leide sprach Adrians kint ### nv wichent Hvnen rechen ir lat mich an den wint ### daz der lvfte erchvele mih stvrme mveden man ### do begvnder an ir willen in strite gegen der tvre gan
###### 1992 | ### Der helt in grozem zorne zvov dem hvse spranch ### waz iteniwer swerte vf sime libe erchlanch ### die niht gesehen heten waz wnders tet sin hant ### die mvsen da beliben von dem vz Burgonden lant
###### 1993 | ### Nv wolde got sprach Dancwart mohte ich den boten han ### der minen brvder Hagenen chvnde wizzen lan ### daz ich vor disen rechen sten in solher not ### er hvlfe mir von hinnen oder er gelege bi mir tot
###### 1994 | ### Do sprachen Hvnen rechen der bote mvstv sin ### so wir dich tragen toten fvr den brvder din ### so siht im erste leide der Gunthers man ### dv hast dem kvnege Ezelen so grozen schaden <hie> getan
| ### Nv lat die dro beliben vn– stet vf hoher baz ### ia getvn ich eteslichem noch die ringe naz ### nv wer mirz swer der welle ich wil ze hove gan ### vn– wil selbe disiv mære minen herren wizzen lan
###### 1996 | ### Er leidete sich so sere den Ezeln man ### daz si in mit den swerten nv torsten niht bestan ### do schvzzen si der gere so vil in sinen rant ### daz er in dvrch die swære mvse lazen von der hant
###### 1997 | ### Si wanden in betwingen do er niht schildes trvoc ### hey waz er tiefer wnden sit dvrch helme slvoc ### des mvse vor im strvochen vil manic kvner man ### darvmbe lop vil grozen der chvne Danchwart gewan
###### 1998 | ### Ze beiden sinen siten si im sprvngen zvo ### ia chom ir eteslicher in den strit ze frvo ### er gie vor sinen vienden alsam ein eberswin ### ze walde tvot vor hvnden wie moehter kvner gesin
###### 1999 | ### Sin vart div wart erniwet von heizem blvte naz ### iane chvnde ein einer reche gestriten nimmer baz ### mit also vil der viende denner hete getan ### do mvsen si in lazen ane ir danc ze hove gan
| ### Trvhsêzzen vn– schenchen die horten swerte chlanc ### vil maniger do daz trinchen von der hende swanch ### vn– svmeliche spise die man ze hove trvoc ### do chom im vor der stiegen der starchen viende genvoc
###### 2001 | ### Wie nv ir gvten knehte sprach der mvde degen ### ia soldet ir der geste gvetliche pflegen ### vn– soldet nv den herren die edeln spise tragen ### vn– liezet [71v]mich div mere ze hove minen herren sagen
###### 2002 | ### Swelher dvrch sin ellen im fvr die stiegen spranch ### der slvger eteslichem so swæren swertes swanc ### daz si dvrch die vorhte vf hoher mvsen stan ### ia het sin starchez ellen vil maniges ende getan
###### 2003 | ### Also der chvne Danehwart vnder die tvre getrat ### daz Ezeln gesinde er hoher wichen bat ### mit blvote bervnnen was allez sin gewant ### ein vil starchez wafen daz trvger bloz an siner hant
###### 2004 | ### Ez was reht in der wile do Danchwart chom fvr die tver ### daz man Ortlieben trvoc wider vn– fver ### von tische ze tischen den fvrsten wol geborn ### von disen starchen mæren wart daz kindelin verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>